@@ -25,12 +25,13 @@
 
 #include <stdint.h>
 
+#include <net/if.h>
 #include <netlink/genl/ctrl.h>
 #include <netlink/genl/genl.h>
 #include <netlink/netlink.h>
 
 #ifndef SOURCE_VERSION
-#define SOURCE_VERSION "2019.0"
+#define SOURCE_VERSION "2019.1"
 #endif
 
 #define EXIT_NOSUCCESS 2
@@ -66,6 +67,7 @@ extern char module_ver_path[];
 enum command_flags {
 	COMMAND_FLAG_MESH_IFACE = BIT(0),
 	COMMAND_FLAG_NETLINK = BIT(1),
+	COMMAND_FLAG_INVERSE = BIT(2),
 };
 
 enum command_type {
@@ -74,7 +76,10 @@ enum command_type {
 };
 
 struct state {
-	char *mesh_iface;
+	char *arg_iface;
+	char mesh_iface[IF_NAMESIZE];
+	unsigned int mesh_ifindex;
+	int vid;
 	const struct command *cmd;
 
 	struct nl_sock *sock;
